echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
echo "" 												>> $EXTENSION/build_order.txt
	
# Required
[[ $(command -v xmllint) == "" ]] && echo "Installing libxml2" && extension --install libxml2 && echo "Finished libxml2"
[[ $(command -v clang) == "" ]] && echo "Installing llvm" && extension --install llvm && echo "Finished llvm"
if [ $(cat /etc/extension/installed_version.list | grep spirv_tools | cut -d \= -f 2) != "1.4.321.0" ]; then 
	echo "Installing spirv_tools" && extension --install spirv_tools:1.4.321.0 && echo "Finished spirv_tools"
fi

if [ $BUILD_ALL == "false" ] && [[ $(command -v llvm-spirv) == "" ]]; then
	echo "spirv_llvm_translator" 						>> $EXTENSION/build_order.txt
fi
if [ $BUILD_ALL == "true" ]; then
	echo "spirv_llvm_translator" 						>> $EXTENSION/build_order.txt
fi
echo "complete _" 										>> $EXTENSION/build_order.txt
